@@ -1,4 +1,4 @@
 # -*- coding: utf-8 -*-
 from xhpy.pylib import *
 name = u"André"
-print <p>{name}</p>
+result = <p>{name}</p>
